OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Invalid Federated Cloud ID",
    "Server to server sharing is not enabled on this server" : "Server to server sharing is not enabled on this server",
    "Couldn't establish a federated share." : "Couldn't establish a federated share.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Couldn't establish a federated share, maybe the password was wrong.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Federated Share request sent, you will receive an invitation. Check your notifications.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "It is not allowed to send federated group shares from this server.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Sharing %1$s failed, because this item is already shared with the account %2$s",
    "Not allowed to create a federated share to the same account" : "Not allowed to create a federated share to the same account",
    "Federated shares require read permissions" : "Federated shares require read permissions",
    "File is already shared with %s" : "File is already shared with %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate.",
    "Could not find share" : "Could not find share",
    "Federated sharing" : "Federated sharing",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "You received {share} as a remote share from {user} (on behalf of {behalf})",
    "You received {share} as a remote share from {user}" : "You received {share} as a remote share from {user}",
    "Accept" : "Accept",
    "Decline" : "Decline",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Sharing" : "Sharing",
    "Federated file sharing" : "Federated file sharing",
    "Provide federated file sharing across servers" : "Provide federated file sharing across servers",
    "Confirm data upload to lookup server" : "Confirm data upload to lookup server",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book.",
    "Enable data upload" : "Enable data upload",
    "Disable upload" : "Disable upload",
    "Confirm querying lookup server" : "Confirm querying lookup server",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "This is used to retrieve the federated cloud ID to make federated sharing easier.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Moreover, email addresses of users might be sent to that system in order to verify them.",
    "Enable querying" : "Enable querying",
    "Disable querying" : "Disable querying",
    "Unable to update federated files sharing config" : "Unable to update federated files sharing config",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)",
    "Allow people on this server to receive shares from other servers" : "Allow people on this server to receive shares from other servers",
    "Allow people on this server to send shares to groups on other servers" : "Allow people on this server to send shares to groups on other servers",
    "Allow people on this server to receive group shares from other servers" : "Allow people on this server to receive group shares from other servers",
    "The lookup server is only available for global scale." : "The lookup server is only available for global scale.",
    "Search global and public address book for people" : "Search global and public address book for people",
    "Allow people to publish their data to a global and public address book" : "Allow people to publish their data to a global and public address book",
    "Trusted federation" : "Trusted federation",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Automatically accept shares from trusted federated accounts and groups by default",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Share with me through my #Nextcloud Federated Cloud ID, see {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Share with me through my #Nextcloud Federated Cloud ID",
    "Share with me via Nextcloud" : "Share with me via Nextcloud",
    "Cloud ID copied" : "Cloud ID copied",
    "Copy" : "Copy",
    "Clipboard not available. Please copy the cloud ID manually." : "Clipboard not available. Please copy the cloud ID manually.",
    "Copied!" : "Copied!",
    "Federated Cloud" : "Federated Cloud",
    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com",
    "Your Federated Cloud ID" : "Your Federated Cloud ID",
    "Share it so your friends can share files with you:" : "Share it so your friends can share files with you:",
    "Bluesky" : "Bluesky",
    "Facebook" : "Facebook",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Add to your website",
    "Share with me via {productName}" : "Share with me via {productName}",
    "HTML Code:" : "HTML Code:",
    "Cancel" : "Cancel",
    "Add remote share" : "Add remote share",
    "Remote share" : "Remote share",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Do you want to add the remote share {name} from {owner}@{remote}?",
    "Remote share password" : "Remote share password",
    "Incoming share could not be processed" : "Incoming share could not be processed",
    "Cloud ID copied to the clipboard" : "Cloud ID copied to the clipboard",
    "Copy to clipboard" : "Copy to clipboard",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialogue. It looks like person@cloud.example.com",
    "X (formerly Twitter)" : "X (formerly Twitter)",
    "formerly Twitter" : "formerly Twitter"
},
"nplurals=2; plural=(n != 1);");
